export interface IRPCProtocol {
    /**
     * Returns a proxy to an object addressable/named in the extension host process or in the renderer process.
     */
    getProxy<T>(identifier: ProxyIdentifier<T>): T;
    /**
     * Register manually created instance.
     */
    set<T, R extends T>(identifier: ProxyIdentifier<T>, instance: R): R;
    /**
     * Assert these identifiers are already registered via `.set`.
     */
    assertRegistered(identifiers: ProxyIdentifier<any>[]): void;
}
export declare class ProxyIdentifier<T> {
    static count: number;
    _proxyIdentifierBrand: void;
    _suppressCompilerUnusedWarning: T;
    readonly isMain: boolean;
    readonly sid: string;
    readonly nid: number;
    readonly hostId: HostIdentifier;
    constructor(isMain: boolean, sid: string, hostId?: HostIdentifier);
}
export declare function createMainContextProxyIdentifier<T>(identifier: string, hostIdentifier?: HostIdentifier): ProxyIdentifier<T>;
export declare function createExtHostContextProxyIdentifier<T>(identifier: string, hostIdentifier?: HostIdentifier): ProxyIdentifier<T>;
export declare function getStringIdentifierForProxy(nid: number): string;
export declare const enum HostIdentifier {
    ServerExtHost = 0,
    ServerMainThread = 1,
    BrowserExtHost = 2,
    BrowserClientThread = 3
}
export declare const enum RequestType {
    /**
     * Process the request on the reciever end
     */
    Process = 0,
    /**
     * Forward the requests to the other end.
     */
    Forward = 1,
    /**
     * Process the request and reply with Forward bit.
     */
    ProcessAndForward = 2
}
export declare const enum TransportType {
    Socket = 0,
    WebSocket = 1
}
